==> haskell-text-latin1-0.3.1-286-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-latin1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-latin1
version:              0.3.1
visibility:           public
id:                   text-latin1-0.3.1-1aJ2h2Q3vJ9GQ9t5H2wsSc
key:                  text-latin1-0.3.1-1aJ2h2Q3vJ9GQ9t5H2wsSc
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-latin1
synopsis:             Latin-1 (including ASCII) utility functions
description:
    This package provides various functions over the ASCII ang Latin-1
    portions of the '\''Char'\'' and '\''Word8'\'' data types.

category:             Text
abi:                  69f98e7f3634dc1c4a49445cf699bc28
exposed:              True
exposed-modules:      Text.Ascii Text.Latin1
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-latin1-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-latin1-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-latin1-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-latin1
hs-libraries:         HStext-latin1-0.3.1-1aJ2h2Q3vJ9GQ9t5H2wsSc
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-2YJdsrn6pUkJFkSDuYKbj5
    data-checked-0.3-2xOO5aVFI22KJDTvb8lvZD
    hashable-1.4.5.0-EdCBZmCkEma7WCMhhvMdNf text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-text-latin1/html/text-latin1.haddock
haddock-html:         /usr/share/doc/haskell-text-latin1/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-latin1-0.3.1-287-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-latin1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-latin1
version:              0.3.1
visibility:           public
id:                   text-latin1-0.3.1-EDcYPthCqkWIOrtdjityAR
key:                  text-latin1-0.3.1-EDcYPthCqkWIOrtdjityAR
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-latin1
synopsis:             Latin-1 (including ASCII) utility functions
description:
    This package provides various functions over the ASCII ang Latin-1
    portions of the '\''Char'\'' and '\''Word8'\'' data types.

category:             Text
abi:                  e1055a9ebfb9a529c352f45211088654
exposed:              True
exposed-modules:      Text.Ascii Text.Latin1
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-latin1-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-latin1-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-latin1-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-latin1
hs-libraries:         HStext-latin1-0.3.1-EDcYPthCqkWIOrtdjityAR
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3W7hj1sdmUw2Fh1p1ue6cC
    data-checked-0.3-2xOO5aVFI22KJDTvb8lvZD
    hashable-1.4.5.0-tUQ3ISdCwwAzRS3LRBhXn text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-text-latin1/html/text-latin1.haddock
haddock-html:         /usr/share/doc/haskell-text-latin1/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
